@@ -2,7 +2,7 @@ use crate::client::Client;
 use serde::{Serialize, Deserialize};
 
 
-#[derive(Debug, Serialize)]
+#[derive(Debug, Serialize, Deserialize)]
 pub struct Message {
 
 }
@@ -12,7 +12,7 @@ pub struct SendResp {
 
 }
 
-#[derive(Debug, Serialize)]
+#[derive(Debug, Serialize, Deserialize)]
 pub struct BatchMessage {
 
 }
